from .base import BaseStylingScore
from .color import ColorScore
from .fontsize import FontsizeScore

# isort: unique-list
__all__ = ["BaseStylingScore", "ColorScore", "FontsizeScore"]
